Package: xxdi
Type: Package
Title: An R Package for Evaluating Expertise Indices for Research
        Strength Assessment
Version: 1.26.4
Authors@R: c(
    person("Nilabhra R", "Das", , "nr.das@yahoo.com", role = c("cre", "aut"), comment = c(ORCID = "0000-0001-8187-0080")),
    person("Abhirup", "Nandy", , "abhirupnandy.online@gmail.com", role = "aut", comment = c(ORCID = "0000-0001-8618-0847"))
  )
Maintainer: Nilabhra R Das <nr.das@yahoo.com>
Description: Institutional performance assessment remains a key challenge to a multitude of stakeholders. Existing indicators such as h-type indicators, g-type indicators, and many others do not reflect expertise of institutions that defines their research portfolio. The package offers functionality to compute and visualise two novel indices: the x-index and the xd-index. The x-index evaluates an institution's scholarly expertise within a specific discipline or field, while the xd-index provides a broader assessment of overall scholarly expertise considering an institution's publication pattern and strengths across coarse thematic areas. These indices offer a nuanced understanding of institutional research capabilities, aiding stakeholders in research management and resource allocation decisions. Lathabai, H.H., Nandy, A., and Singh, V.K. (2021) <doi:10.1007/s11192-021-04188-3>. Nandy, A., Lathabai, H.H., and Singh, V.K. (2023) <doi:10.5281/zenodo.8305585>. This package provides the h-, g-, x-, xd-indices, and their variants for use with standard format of Web of Science (WoS) scrapped datasets.
License: GPL-3
Depends: R (>= 4.4.2.0)
Imports: agop (>= 0.2.4), dplyr (>= 1.1.4), ggplot2 (>= 3.5.0), stats
        (>= 4.3.3), tidyr (>= 1.3.1)
Encoding: UTF-8
RoxygenNote: 7.3.3
LazyData: true
NeedsCompilation: no
Packaged: 2026-04-29 13:11:30 UTC; nilabhra.das
Author: Nilabhra R Das [cre, aut] (ORCID:
    <https://orcid.org/0000-0001-8187-0080>),
  Abhirup Nandy [aut] (ORCID: <https://orcid.org/0000-0001-8618-0847>)
Repository: CRAN
Date/Publication: 2026-04-30 08:30:02 UTC
Built: R 4.5.2; ; 2026-05-01 19:10:49 UTC; unix
