# Generated by roxygen2: do not edit by hand

export(g_index)
export(h_index)
export(ivw_xd_index)
export(x_index)
export(xc_index)
export(xd_index)
export(xo_index)
importFrom(agop,index.g)
importFrom(agop,index.h)
importFrom(dplyr,"%>%")
importFrom(dplyr,arrange)
importFrom(dplyr,desc)
importFrom(dplyr,filter)
importFrom(dplyr,mutate)
importFrom(dplyr,row_number)
importFrom(dplyr,select)
importFrom(ggplot2,aes)
importFrom(ggplot2,element_text)
importFrom(ggplot2,geom_point)
importFrom(ggplot2,geom_segment)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,ggtitle)
importFrom(ggplot2,theme)
importFrom(ggplot2,xlab)
importFrom(ggplot2,ylab)
importFrom(stats,na.omit)
importFrom(tidyr,separate_rows)
